pub struct UseModule {
name: SyntheticMacroPath<SyntheticMacroModule>,
beta_mods: Enabled,
}Expand description
A single use Module;
Could come from a template definition preamble, or the start of the body of a module itself.
Fields
name: SyntheticMacroPath<SyntheticMacroModule>beta_mods: EnabledImplementations
Sourceimpl UseModule
impl UseModule
pub fn parse_several(input: ParseStream<'_>) -> Result<Vec<Self>>